/**
 * EasyBeans
 * Copyright (C) 2006-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxEjbLocalHomeVisitor.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.ObjectAnnotationVisitor;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.scan.api.IType;

/**
 * This class manages the handling of &#64;{@link javax.ejb.LocalHome} annotation.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent Benoit
 */
public class JavaxEjbLocalHomeVisitor<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>>
        extends ObjectAnnotationVisitor<C, IType> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/LocalHome;";

    /**
     * Constructor.
     * @param classAnnotationMetadata linked to a class metadata
     */
    public JavaxEjbLocalHomeVisitor(final C classAnnotationMetadata) {
        super(classAnnotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br> Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        IType t = getValue();
        String className = t.getInternalName();
        getAnnotationMetadata().setLocalHome(className);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }

}
